@@ -2,7 +2,7 @@ import lightning as L
 import torch
 from torch.utils.data import DataLoader, random_split, TensorDataset
 from typing import Optional
-from spotpython.utils.split import calculate_data_split
+from math import floor
 
 
 class LightDataModule(L.LightningDataModule):
@@ -119,6 +119,24 @@ class LightDataModule(L.LightningDataModule):
         except Exception as e:
             raise ValueError(f"Error transforming dataset: {e}")
 
+    def handle_scaling_and_transform(self) -> None:
+        """
+        Fits the scaler on the training data and transforms both training and validation datasets.
+        This function is only called when self.scaler is not None.
+        """
+        # Ensure self.scaler is not None before proceeding
+        if self.scaler is None:
+            raise ValueError("Scaler object is required to perform scaling and transformation.")
+        # Fit the scaler on training data
+        scaler_train_data = torch.stack([self.data_train[i][0] for i in range(len(self.data_train))]).squeeze(1)
+        if self.verbosity > 0:
+            print(scaler_train_data.shape)
+        self.scaler.fit(scaler_train_data)
+        # Transform the training data
+        self.data_train = self.transform_dataset(self.data_train)
+        # Transform the validation data
+        self.data_val = self.transform_dataset(self.data_val)
+
     def prepare_data(self) -> None:
         """Prepares the data for use."""
         # download
@@ -148,12 +166,19 @@ class LightDataModule(L.LightningDataModule):
                 Training set size: 3
 
         """
-        full_train_size, val_size, train_size, test_size = calculate_data_split(
-            test_size=self.test_size,
-            full_size=len(self.data_full),
-            verbosity=self.verbosity,
-            stage=stage,
-        )
+        full_size = len(self.data_full)
+        test_size = self.test_size
+
+        # consider the case when test_size is a float
+        if isinstance(self.test_size, float):
+            full_train_size = 1.0 - self.test_size
+            val_size = full_train_size * self.test_size
+            train_size = full_train_size - val_size
+        else:
+            # test_size is an int, training size calculation directly based on it
+            full_train_size = full_size - self.test_size
+            val_size = floor(full_train_size * self.test_size / full_size)
+            train_size = full_size - val_size - test_size
 
         # Assign train/val datasets for use in dataloaders
         if stage == "fit" or stage is None:
@@ -161,23 +186,16 @@ class LightDataModule(L.LightningDataModule):
                 print(f"train_size: {train_size}, val_size: {val_size} used for train & val data.")
             generator_fit = torch.Generator().manual_seed(self.test_seed)
             self.data_train, self.data_val, _ = random_split(self.data_full, [train_size, val_size, test_size], generator=generator_fit)
+            # Handle scaling and transformation if scaler is provided
             if self.scaler is not None:
-                # Fit the scaler on training data
-                scaler_train_data = torch.stack([self.data_train[i][0] for i in range(len(self.data_train))]).squeeze(1)
-                if self.verbosity > 0:
-                    print(scaler_train_data.shape)
-                self.scaler.fit(scaler_train_data)
-                # Transform the training data
-                self.data_train = self.transform_dataset(self.data_train)
-                # Transform the validation data
-                self.data_val = self.transform_dataset(self.data_val)
+                self.handle_scaling_and_transform()
 
         # Assign test dataset for use in dataloader(s)
         if stage == "test" or stage is None:
             if self.verbosity > 0:
                 print(f"test_size: {test_size} used for test dataset.")
             generator_test = torch.Generator().manual_seed(self.test_seed)
-            self.data_test, _ = random_split(self.data_full, [test_size, full_train_size], generator=generator_test)
+            self.data_test, _, _ = random_split(self.data_full, [test_size, train_size, val_size], generator=generator_test)
             if self.scaler is not None:
                 # Transform the test data
                 self.data_test = self.transform_dataset(self.data_test)
@@ -187,7 +205,7 @@ class LightDataModule(L.LightningDataModule):
             if self.verbosity > 0:
                 print(f"test_size: {test_size} used for predict dataset.")
             generator_predict = torch.Generator().manual_seed(self.test_seed)
-            self.data_predict, _ = random_split(self.data_full, [test_size, full_train_size], generator=generator_predict)
+            self.data_predict, _, _ = random_split(self.data_full, [test_size, train_size, val_size], generator=generator_predict)
             if self.scaler is not None:
                 # Transform the predict data
                 self.data_predict = self.transform_dataset(self.data_predict)
@@ -264,7 +282,6 @@ class LightDataModule(L.LightningDataModule):
             print(f"LightDataModule.test_dataloader(). Test set size: {len(self.data_test)}")
         # print(f"LightDataModule: test_dataloader(). batch_size: {self.batch_size}")
         # print(f"LightDataModule: test_dataloader(). num_workers: {self.num_workers}")
-        # apply fit_transform to the val data
         return DataLoader(self.data_test, batch_size=self.batch_size, num_workers=self.num_workers)
 
     def predict_dataloader(self) -> DataLoader:
