@@ -26,6 +26,7 @@ def cv_model(config: dict, fun_control: dict) -> float:
         >>> fun_control = {
         ...     "_L_in": 10,
         ...     "_L_out": 1,
+        ...     "_L_cond": 0,
         ...     "enable_progress_bar": True,
         ...     "core_model": MyModel,
         ...     "num_workers": 4,
@@ -38,6 +39,7 @@ def cv_model(config: dict, fun_control: dict) -> float:
     """
     _L_in = fun_control["_L_in"]
     _L_out = fun_control["_L_out"]
+    _L_cond = fun_control["_L_cond"]
     _torchmetric = fun_control["_torchmetric"]
     if fun_control["enable_progress_bar"] is None:
         enable_progress_bar = False
@@ -52,7 +54,7 @@ def cv_model(config: dict, fun_control: dict) -> float:
     for k in range(num_folds):
         print("k:", k)
 
-        model = fun_control["core_model"](**config, _L_in=_L_in, _L_out=_L_out, _torchmetric=_torchmetric)
+        model = fun_control["core_model"](**config, _L_in=_L_in, _L_out=_L_out, _L_cond=_L_cond, _torchmetric=_torchmetric)
 
         dm = LightCrossValidationDataModule(
             k=k,
@@ -86,9 +88,7 @@ def cv_model(config: dict, fun_control: dict) -> float:
                 default_hp_metric=True,
                 log_graph=fun_control["log_graph"],
             ),
-            callbacks=[
-                EarlyStopping(monitor="val_loss", patience=config["patience"], mode="min", strict=False, verbose=False)
-            ],
+            callbacks=[EarlyStopping(monitor="val_loss", patience=config["patience"], mode="min", strict=False, verbose=False)],
             enable_progress_bar=enable_progress_bar,
         )
         # Pass the datamodule as arg to trainer.fit to override model hooks :)
